# yaddy
Yet Another Domain (Driven) Development librarY for Python

Warning: This repository is in WIP (Work In Progress) state. None
of the APIs are fixed, do not use it in your production environment.

yaddy is a library that provides a basis for DDD (Domain Driven
Development) in python. It is mostly developed for my own needs,
but any suggestions are appreciated.

## Tests

High-level (acceptance, e2e) tests
could be run with:

```Shell
poetry run accept
```

Developer (unit) tests could be run
with:

```Shell
poetry run unit
```